zscroll

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 29, 2020 License: MIT Imports: 4 Imported by: 0

README

zscroll-go

zscroll is a text scroller for panels or terminals.

Installation

Get the binary from GitHub Releases.

Or, if you have Go, you can install zscroll with the following command.

go get github.com/skmatz/zscroll-go/...

Usage

Now, refer to the original repository (here).

References

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Scroller

type Scroller struct {
	Text string

	AfterText   string
	BeforeText  string
	Delay       float64
	Length      int
	NewLine     bool
	PaddingText string
	Reverse     bool
	Scroll      bool
	Timeout     int
	// contains filtered or unexported fields
}

func NewScroller

func NewScroller(text string, opt ScrollerOptions) (*Scroller, error)

func (*Scroller) CurrentString

func (s *Scroller) CurrentString() string

func (*Scroller) Run

func (s *Scroller) Run() error

type ScrollerOptions

type ScrollerOptions struct {
	AfterText   string
	BeforeText  string
	Delay       float64
	Length      int
	NewLine     bool
	PaddingText string
	Reverse     bool
	Scroll      bool
	Timeout     int
}

Directories

Path Synopsis
cmd
zscroll command

Jump to